@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: optparse-simple
 version: 0.0.3
-id: optparse-simple-0.0.3-a4301f150bb60aff6fc7345301def460
-key: optpa_IBelsCRzKmTLJHuWYiL3w2
+id: optparse-simple-0.0.3-c943b0a6f5a1ba8fd4349701ea16e51c
+key: optpa_E7FpOzx43xQHpAVE5o5atY
 license: BSD3
 copyright: 2015 FP Complete
 maintainer: chrisdone@fpcomplete.com
@@ -19,10 +19,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/optparse-simple-0.0.3
-hs-libraries: HSoptparse-simple-0.0.3-IBelsCRzKmTLJHuWYiL3w2
+hs-libraries: HSoptparse-simple-0.0.3-E7FpOzx43xQHpAVE5o5atY
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    either-4.4.1-fa2594a98ce0054c95ba353e8b66d325
+    either-4.4.1-0ad66f7e12d699216df063a503e72063
     gitrev-1.2.0-e94a60465b66be18f7d5d663af7880a5
     optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
